#### Red Hat Package Specification File
#
# File: Fnorb-1.0.spec
#
# An independent 'BuildRoot:' directive is used so that that this package
# can be built in the /tmp directory, for the case where the existing setup
# on the build host would be disrupted by installing-after-build-to-package
# onto that system.
#
# Sample Package Names:
#   Fnorb-1.0-1.i386.rpm
#
# Modification History:
# 02-Sep-98 jrr Packaged Release 0.7.1
# 24-Nov-98 jrr Updated to Release 0.8
# 26-Feb-99 jrr Updated to Release 1.0 beta 1
# 11-Apr-99 jrr Fixed Boot-Time Priorities re ChkConfig Descriptive Info
# 05-May-99 jrr Updated to Release 1.0 Final Version
#
# To-Do:
#   Devise a scheme to kill a Python script, since the normal /etc/rc.d/init.d
#   scripts don't do the job.
#
#   Find out why these RPMs don't de-install cleanly re leaving *.pyc files
#   lying about.
#
#   Fix the precompiled .pyc files to contain reasonable paths, somehow.
#
####

####
# Section: Preamble (Items Displayed When Users Request Info About Package)
#
# The order of the entries below is unimportant.
#
####

### %{PACKAGE_VERSION}

Name:               Fnorb
Version:            1.0
Release:            1
Copyright:          Free for Non-Commercial (Resale) Use
#Distribution:       TauISP
Vendor:             University of Queensland
URL:                http://www.dstc.edu.au/Fnorb
Packager:           Jeff Rush <jrush@summit-research.com>
BuildArchitectures: i386
BuildRoot:          /tmp/Fnorb-1.0-rootdir
Summary:            CORBA 2.0 ORB written in Python
Group:              Networking/Frameworks
Requires:           python

Source0: Fnorb-1.0.tar.gz
Source1: Fnorb-1.0.naming.init
Source2: Fnorb-1.0.naming.sh
Source3: Fnorb-1.0.naming.csh
Source4: Fnorb-1.0.ifrepo.init
Source5: Fnorb-1.0.ifrepo.sh
Source6: Fnorb-1.0.ifrepo.csh
Source7: Fnorb-1.0.README.TOO
Source8: Fnorb-Guide.pdf

%description
A CORBA 2.0 ORB written in Python, a mature, interpreted, object-oriented
programming language with powerful high-level datatypes that make it
ideally suited as a scripting language for CORBA.

Fnorb supports all CORBA 2.0 datatypes (including Any's) and provides
a full implementation of IIOP.  Fnorb is simple, light-weight, and easy
to install and use.

%package naming
Summary:            Naming Service Daemon for Fnorb CORBA ORB
Group:              Networking/Frameworks
Requires:           python Fnorb
Prereq:             chkconfig

%description naming
A server daemon that provides a standard Naming Service to CORBA objects.
It provides a mapping between a name and an object reference, so that
objects can be found more easily.  Think of it as a white pages lookup
system for CORBA.

%package ifrepo
Summary:            Interface Repository Daemon for Fnorb CORBA ORB
Group:              Networking/Frameworks
Requires:           python Fnorb
Prereq:             chkconfig

%description ifrepo
A server daemon that maintains a database of registered IDL interfaces,
for dynamic invocation as well as a variety of report generation and
interface introspection tools.

########################################

########## 
#
# The following environment variables are automatically defined for use
# in any of the following shell scripts:
#
#   RPM_SOURCE_DIR      { where sources originally reside }
#   RPM_BUILD_DIR       { where sources get unpacked into }
#   RPM_DOC_DIR
#   RPM_OPT_FLAGS
#   RPM_ARCH
#   RPM_OS
#   RPM_ROOT_DIR
#   RPM_BUILD_ROOT      { where final images get placed before packaging }
#   RPM_PACKAGE_NAME
#   RPM_PACKAGE_VERSION
#   RPM_PACKAGE_RELEASE
#
##########

####
# Section: Prep Script (Prepare to Build; Usually Just Unpacking the Sources)
####
%prep
%setup

####
# Section: Build Script (Actually Perform the Build; Usually Just 'make')
####
%build
chmod +x script/fn*
cd src
make -f Makefile.pre.in boot
make

####
# Section: Install-After-Build Script (Often Just 'make install')
####
%install

  # Make the Necessary Directories
  install -m755 --directory   $RPM_BUILD_ROOT/usr/bin
  install -m755 --directory   $RPM_BUILD_ROOT/usr/lib/python1.5/Fnorb
  install -m755 --directory   $RPM_BUILD_ROOT/usr/lib/python1.5/lib-dynload
  install -m755 --directory   $RPM_BUILD_ROOT/etc/rc.d/init.d
  install -m755 --directory   $RPM_BUILD_ROOT/etc/fnaming.db
  install -m755 --directory   $RPM_BUILD_ROOT/etc/profile.d

  # Precompile Python Source for Faster Imports During Usage
  # (Since user of package may not have write-access to install directory)
  python /usr/lib/python1.5/compileall.py compiler
  python /usr/lib/python1.5/compileall.py cos
  python /usr/lib/python1.5/compileall.py orb
  python /usr/lib/python1.5/compileall.py parser

  # Then Move It All into Place under the Root of the Build Directory
  chmod -R +w                 $RPM_BUILD_ROOT/usr/lib/python1.5/Fnorb
  install -m644 __init__.py   $RPM_BUILD_ROOT/usr/lib/python1.5/Fnorb
  install -m644 etc/fnorb.cfg $RPM_BUILD_ROOT/etc

  cp -rp        compiler/     $RPM_BUILD_ROOT/usr/lib/python1.5/Fnorb/
  cp -rp        cos/          $RPM_BUILD_ROOT/usr/lib/python1.5/Fnorb/
  cp -rp        orb/          $RPM_BUILD_ROOT/usr/lib/python1.5/Fnorb/
  cp -rp        parser/       $RPM_BUILD_ROOT/usr/lib/python1.5/Fnorb/
  cp -rp        script/       $RPM_BUILD_ROOT/usr/lib/python1.5/Fnorb/

  cp  -p        script/*      $RPM_BUILD_ROOT/usr/bin/
  chmod -R +w                 $RPM_BUILD_ROOT/usr/bin
  rm  -f                      $RPM_BUILD_ROOT/usr/bin/__init__.py
  rm  -f                      $RPM_BUILD_ROOT/usr/bin/fnidl.py

  install -m755 src/bisonmodule.so $RPM_BUILD_ROOT/usr/lib/python1.5/lib-dynload
  install -m755 src/cdrmodule.so   $RPM_BUILD_ROOT/usr/lib/python1.5/lib-dynload

  install -m755 $RPM_SOURCE_DIR/Fnorb-1.0.naming.init $RPM_BUILD_ROOT/etc/rc.d/init.d/naming
  install -m755 $RPM_SOURCE_DIR/Fnorb-1.0.naming.sh   $RPM_BUILD_ROOT/etc/profile.d/naming.sh
  install -m755 $RPM_SOURCE_DIR/Fnorb-1.0.naming.csh  $RPM_BUILD_ROOT/etc/profile.d/naming.csh

  install -m755 $RPM_SOURCE_DIR/Fnorb-1.0.ifrepo.init $RPM_BUILD_ROOT/etc/rc.d/init.d/ifrepo
  install -m755 $RPM_SOURCE_DIR/Fnorb-1.0.ifrepo.sh   $RPM_BUILD_ROOT/etc/profile.d/ifrepo.sh
  install -m755 $RPM_SOURCE_DIR/Fnorb-1.0.ifrepo.csh  $RPM_BUILD_ROOT/etc/profile.d/ifrepo.csh

  install -m755 $RPM_SOURCE_DIR/Fnorb-1.0.README.TOO  $RPM_BUILD_DIR/Fnorb-1.0/README.TOO

####
# Section: Delivery Install/Uninstall Scripts (Pre/Post Install/Erase Scripts)
####
%post naming
  /sbin/chkconfig --add naming
  cat <<EOF

	Fnorb Naming Service Post-Installation Note:

	To start up the Naming Service without rebooting, enter
	the following while logged in as the root user:

	    /etc/rc.d/init.d/naming start

	And then log out and back in to pick up the change in
	your shell's FNORB_NAMING_SERVICE environment variable
	that gets set from the script in /etc/profile.d/.
EOF

%post ifrepo
  /sbin/chkconfig --add ifrepo
  cat <<EOF

	Fnorb Interface Repository Service Post-Installation Note:

	To start up the Interface Repository Service without
	rebooting, enter the following while logged in as the
	root user:

	    /etc/rc.d/init.d/ifrepo start

	And then log out and back in to pick up the change in
	your shell's FNORB_INTERFACE_REPOSITORY environment
	variable that gets set from the script in /etc/profile.d/.
EOF

%preun naming
if [ "$1" = 0 ] ; then
  /sbin/chkconfig --del naming
fi

%preun ifrepo
if [ "$1" = 0 ] ; then
  /sbin/chkconfig --del ifrepo
fi

####
# Section: Verify Script (Check for Proper Installation of Package)
####

####
# Section: Clean Script (Tidy Up Build Area After a Build Completes)
####
%clean
  rm -rf $RPM_BUILD_ROOT

####
# Section: Files (List of Files w/Attributes Making Up Package)
####
%files

  %defattr(-, root, wheel)
  %doc ANNOUNCE
  %doc CHANGES
  %doc LICENSE.HTML
  %doc README README.TOO
  %doc doc/Fnorb-Guide.doc
  %doc doc/Fnorb-Guide.pdf
  %doc examples/

  /usr/lib/python1.5/Fnorb
  /usr/lib/python1.5/lib-dynload
  /usr/bin

%files naming
  %defattr(-, root, wheel)

  %config /etc/rc.d/init.d/naming
  %config /etc/profile.d/naming.sh
  %config /etc/profile.d/naming.csh
  %dir    /etc/fnaming.db

%files ifrepo
  %defattr(-, root, wheel)

  %config /etc/rc.d/init.d/ifrepo
  %config /etc/profile.d/ifrepo.sh
  %config /etc/profile.d/ifrepo.csh

#-r--r--r--    664 Fnorb-1.0/etc/fnorb.cfg
